@@ -16,7 +16,7 @@
 import typing
 
 from decimal import Decimal
-from pyserum.market import Market as PySerumMarket
+from pyserum.market.market import Market as PySerumMarket
 from pyserum.market.orderbook import OrderBook as PySerumOrderBook
 from solana.publickey import PublicKey
 
@@ -36,8 +36,11 @@ from .token import Token
 # This class encapsulates our knowledge of a Serum spot market.
 #
 class SpotMarket(LoadedMarket):
-    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token, group: Group, underlying_serum_market: PySerumMarket):
+    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token,
+                 group: Group, underlying_serum_market: PySerumMarket) -> None:
         super().__init__(serum_program_address, address, InventorySource.ACCOUNT, base, quote, RaisingLotSizeConverter())
+        self.base: Token = base
+        self.quote: Token = quote
         self.group: Group = group
         self.underlying_serum_market: PySerumMarket = underlying_serum_market
         base_lot_size: Decimal = Decimal(underlying_serum_market.state.base_lot_size())
@@ -75,11 +78,12 @@ class SpotMarket(LoadedMarket):
 #
 # This class holds information to load a `SpotMarket` object but doesn't automatically load it.
 #
-
-
 class SpotMarketStub(Market):
-    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token, group_address: PublicKey):
+    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token,
+                 group_address: PublicKey) -> None:
         super().__init__(serum_program_address, address, InventorySource.ACCOUNT, base, quote, RaisingLotSizeConverter())
+        self.base: Token = base
+        self.quote: Token = quote
         self.group_address: PublicKey = group_address
 
     def load(self, context: Context, group: typing.Optional[Group]) -> SpotMarket:
